@@ -104,7 +104,7 @@ class BTInterface(AbstractInterface):
         pass
     gobject.idle_add(self.run_commands, False)
 
-  def turn_mode(self, mode):
+  def turn_mode(self, mode, startup):
     gobject.idle_add(self.run_mode_commands, mode)
 
   def run_commands(self, flag):
