@@ -92,8 +92,10 @@ class GSMInterface(AbstractInterface):
         if self.get_config_value('show-signal-strength'):
           strength = self.get_strength()
         sp_info = self.get_interface('SIM').get_service_provider_name()
-        self.process_signal_operator(None, sp_info[0])
+        if sp_info:
+          self.process_signal_operator(None, sp_info[0])
       else: #'activation_failed', 'selection_failed'
+        print value
         result = InterfaceState.on
       #return 1 + ['activation_pending', 'online'].index(str(value)), 
       return result, self.get_mode(), strength
