@@ -15,11 +15,11 @@ class WLANInterface(AbstractInterface):
   wifi_module_path = '/org/freedesktop/Hal/Manager'
   wifi_module_iface = 'org.freedesktop.Hal.Manager'
   wifi_module_signal = None
-  wifi_cmd = {'up': 'sudo /usr/bin/advifsw_wlan_up.sh',
-              'down': 'sudo /usr/bin/advifsw_wlan_down.sh',
-              'unload': 'sudo /usr/bin/advifsw_wlan_unload.sh',
-              'load0': 'sudo /usr/bin/advifsw_wlan_load0.sh',
-              'load1': 'sudo /usr/bin/advifsw_wlan_load1.sh',
+  wifi_cmd = {'up': 'sudo /usr/bin/advifsw/wlan_up.sh',
+              'down': 'sudo /usr/bin/advifsw/wlan_down.sh',
+              'unload': 'sudo /usr/bin/advifsw/wlan_unload.sh',
+              'load0': 'sudo /usr/bin/advifsw/wlan_load0.sh',
+              'load1': 'sudo /usr/bin/advifsw/wlan_load1.sh',
               'get_driver': "lsmod | grep '^wl12\([x]\{2\}\|51\)\ ' | sed -n s/\ .*//p",
               'check_be': 'if [ -d /lib/modules/`uname -r` ]; then echo 1; fi'
              }
