@@ -16,10 +16,12 @@ class AISLocale(Locale):
     self.current_dict = {'item-Bluetooth': 'Bluetooth',
                          'item-GSM': 'GSM',
                          'item-WLAN': 'WLAN',
-                         'item-On': 'On',
-                         'item-Off': 'Off',
-                         'item-Connected': 'Connected',
-                         'item-<>': '<>',
+                         'On': 'On',
+                         'Off': 'Off',
+                         'Connected': 'Connected',
+                         '<>': '<>',
+                         'Connecting': 'Connecting',
+                         'Disconnecting': 'Disconnecting',
                          'settings-other': 'Other',
                          'item-gsm-3g+gsm': '3G+GSM',
                          'item-gsm-2g': '2G',
